#
# spec file for package irqbalance
#
# Copyright (c) 2023 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


#Compat macro for new _fillupdir macro introduced in Nov 2017
%if ! %{defined _fillupdir}
  %define _fillupdir %{_localstatedir}/adm/fillup-templates
%endif
Name:           irqbalance
Version:        1.9.3.10.git+1a7d461
Release:        1.1
Summary:        Daemon to balance IRQs on SMP machines
License:        GPL-2.0-or-later
Group:          System/Daemons
URL:            https://github.com/Irqbalance/irqbalance
#Source:         https://github.com/Irqbalance/irqbalance/archive/refs/tags/v%%{version}.tar.gz#/%%{name}-%%{version}.tar.gz
Source:         %{name}-%{version}.tar.gz
Source3:        sysconfig.irqbalance
Patch1:         Set-fd-limit.patch
BuildRequires:  libcap-ng-devel
BuildRequires:  libtool
BuildRequires:  ncurses-devel
BuildRequires:  pkgconfig
BuildRequires:  pkgconfig(glib-2.0)
BuildRequires:  pkgconfig(libsystemd)
Requires(pre):  %fillup_prereq
Recommends:     %{name}-ui
ExcludeArch:    s390 s390x
%{?systemd_ordering}
%ifarch x86_64 %{?x86_64}
BuildRequires:  pkgconfig(libnl-3.0)
%endif
%ifnarch %{arm}
BuildRequires:  libnuma-devel
%endif

%description
irqbalance dynamically switches the CPUs for IRQs to prevent cpu0 from
being used for all IRQs.

%package ui
Summary:        UI for IRQ balance Daemon
Group:          System/Daemons
Requires:       %{name} = %{version}

%description ui
Text UI for the IRQ balance daemon.

%prep
%setup -q
%autopatch -p1

%build
NOCONFIGURE=1 ./autogen.sh
%configure \
    --with-systemd \
%ifarch x86_64 %{?x86_64}
    --enable-thermal
%endif

%make_build LDFLAGS="-Wl,-z,relro,-z,now" CFLAGS="%{optflags} -fPIE -pie $(ncurses6-config --cflags)" LDFLAGS="$(ncurses6-config --libs)"
cp %{SOURCE3} .

%install
%make_install

mkdir -p %{buildroot}%{_fillupdir}/
install -m 0644 sysconfig.irqbalance %{buildroot}%{_fillupdir}/
sed -ie "s|EnvironmentFile=.*|EnvironmentFile=%{_sysconfdir}/sysconfig/irqbalance|g" misc/irqbalance.service
# Remove syslog.target in systemd service file; not provided by systemd anymore
sed -ie "s|After=syslog.target||g" misc/irqbalance.service
install -D -m 0644 misc/irqbalance.service %{buildroot}%{_unitdir}/irqbalance.service
ln -s %{_sbindir}/service %{buildroot}%{_sbindir}/rcirqbalance

%check
%make_build check

%pre
%service_add_pre irqbalance.service

%post
%fillup_only %{name}
%service_add_post irqbalance.service

%preun
%service_del_preun irqbalance.service

%postun
%service_del_postun irqbalance.service

%files
%license COPYING
%doc AUTHORS README.md
%{_sbindir}/irqbalance
%{_sbindir}/rcirqbalance
%{_unitdir}/irqbalance.service
%{_mandir}/man1/irqbalance.1%{?ext_man}
%{_fillupdir}/sysconfig.irqbalance

%files ui
%{_sbindir}/irqbalance-ui
%{_mandir}/man1/irqbalance-ui.1%{?ext_man}

%changelog
* Wed Dec  6 2023 aschnell@suse.com
- Update to version 1.9.3.10.git+1a7d461:
  * filter console only output when using journal mode
- build with libsystemd for logging (bsc#1217754)
* Tue Nov 21 2023 trenn@suse.de
- Update to version 1.9.3.8.git+c963f48:
  * Enable systemd feature support by default when building with meson
  * Add support for linking against libnl when building with meson
  * Turn NUMA support into an enabled feature, when building with meson
  * Set project version of meson build to 1.9.3
  * Install man pages when building with meson
  * When building with meson, make sure to link against numa
  * Updating to version 1.9.3
  * Automatically use systemd journal and run in foreground when under systemd
* Mon Aug 21 2023 trenn@suse.de
- Update to version 1.9.2.34.git+5069982:
  * activate_mapping: avoid logging error when there is none
  * activate_mapping: only blacklist irq if error is considered permanent
  * activate_mapping: report error reason
  * activate_mapping: make sure to catch all errors
  * activate_mapping: avoid use-after-free when affinity cannot be set
  * Revert "activate_mapping: fflush the buffered data to smp_affinity"
  * activate_mapping: fflush the buffered data to smp_affinity
* Mon Jun 26 2023 trenn@suse.de
- Resurrect _service file and old git patch no versioning
  A _service
  A _servicedata
  A irqbalance.obsinfo
- Update to version 1.9.2.24.git+184c950:
  * procinterrupts: fix initialisation of regex_t struct
  * Fix it so we actually stop when we hit an interrupt condition
  * Fix signedness of error handling
  * Revert "Fix CPU number condition in service file"
  * Issue 259: select NL_SKIP / NL_STOP based on error
  * fix CPU number condition in service file
- Already included upstream:
  D irqbalance-systemd-netlink.patch
* Fri Dec 16 2022 Dirk Müller <dmueller@suse.com>
- build for x86_64 subarchs the same way like for baseline
* Fri Nov 11 2022 Dirk Müller <dmueller@suse.com>
- add irqbalance-systemd-netlink.patch (related to bsc#1205308)
* Mon Nov  7 2022 Dirk Müller <dmueller@suse.com>
- update to 1.9.2:
  * avoid coredump on build_one_dev_entry()
  * avoid double free on deinit_thermal()
  * change the log level in thermal.c
  * fix a minor typo
- drop Avoid-double-free-on-deinit_thermal.patch, uninitialized.patch: (upstream)
* Tue Oct 25 2022 Dirk Müller <dmueller@suse.com>
- run tests
- add Avoid-double-free-on-deinit_thermal.patch (bsc#1204607)
* Tue Oct 18 2022 Dirk Müller <dmueller@suse.com>
- add uninitialized.patch (bsc#1204371)
- build with thermald support on x86_64 (jsc#PED-1039)
* Thu Oct 13 2022 Dirk Müller <dmueller@suse.com>
- update to 1.9.1:
  * get irq->module relationship from /sys/bus/pci/*/driver
  * ensure --banmod is respected
  * check whether savedptr is NULL before invoking strlen
  * add meson
  * support thermal events
  * fix irqbalance never exits
  * irqbalance-ui: able to scroll and show coulist and irqs' name
- drop proc-interrupts.patch (upstream)
  D proc-interrupts.patch
* Wed Aug 17 2022 dmueller@suse.com
- Update to version 1.9.0:
  * correct wait time in oneshot mode
  * Document updates
  * disable irqbalance when we only have a single cpu/cache domain
  * fix UI to fetch full messages from UNIX socket
  * avoid some buffer overflows
  * fix UI printf style formatting
  * drop bounding set from irqbalance
* Mon Jun 27 2022 Andreas Schwab <schwab@suse.de>
- proc-interrupts.patch: parse_proc_interrupts: fix parsing interrupt
  counts
* Wed Sep  8 2021 trenn@suse.de
- Update to version 1.8.0.18.git+2435e8d:
  * fix unsigned integer subtraction sign overflow
  * fix opendir fails in check_platform_device
  * irqbalance: Check validity of numa_node
  * configure.ac: use pkg-config to find numa
  * Disable the communication socket when UI is disabled
  * Fix comma typo in ui.c
  * drop NoNewPrivs from irqbalance service
  * remove no existing irq in banned_irqs
  * Fix compile issue with none AARCH64 builds
* Wed Sep  8 2021 Thomas Renninger <trenn@suse.de>
- Fixes integrated mainline:
  * bsc#1119461
  * bsc#1138190
  * bsc#1154905
  * bsc#1178477 bsc#1183405 (removed patches due to mainline integration):
    procinterrupts-check-xen-dyn-event-more-flexible.patch
  * bsc#1182254 bsc#1156315 (removed patches due to mainline integration):
    fix-ambiguous-parsing-of-node-entries-in-sys.patch
  * bsc#1183157
    also-fetch-node-info-for-non-PCI-devices.patch
* Tue Aug 31 2021 trenn@suse.de
- Update to version 1.8.0.18.git+2435e8d.obscpio:
  * fix unsigned integer subtraction sign overflow
- Make git hash in version better visable .git+<githash>
* Wed Aug 11 2021 trenn@suse.de
- Update to version 1.8.0.14.ga7f8148:
  * irqbalance: Check validity of numa_node
  * configure.ac: use pkg-config to find numa
  * Disable the communication socket when UI is disabled
- Use %%{?systemd_ordering} instead of %%{?systemd_requires}
* Mon Jul 12 2021 trenn@suse.de
- Update to version 1.8.0.8.gbd5aaf5 (jsc#SLE-17697):
  * Fix comma typo in ui.c
  * drop NoNewPrivs from irqbalance service
  * remove no existing irq in banned_irqs
  * Fix compile issue with none AARCH64 builds
  * Fix irqbalance cannot obtain the full name of irq
- Enhance _service magic and add git hashtag to version
* Tue Apr 13 2021 trenn@suse.de
- Add _service file pointing to github sources
  A _service
- Update to version 1.8.0:
  * Add return value check of opendir in do_one_cpu
  * Hotplug may occur again during sleep, so wait until there is no hotplug
* Wed Mar 10 2021 trenn@suse.de
- Update to version 1.7.0+git20210222.9db8d5c:
  * ui: fix cpu/irq menu off by one
  * fix uint64_t printf format (use PRIu64)
  * Also fetch node info for non-PCI devices
  * Add hot pull method for irqbalance
  * Add log for hotplug appropriately
  * add irq hotplug feature for irqbalance
  * Remove some unused constant macros in constants.h
  * Add a deprecation notice for IRQBALANCE_BANNED_CPUS
  * Add IRQBALANCE_BANNED_CPULIST to env file
  * log correctly for isolated and nohz_full cpus
  * Update README.md
  * Add some examples for IRQBALANCE_BANNED_CPUS
  * Adjust how we determine if a cpu is online
  * activate_mapping: activate only online CPUs
  * add env variable to ban cpus using cpulist syntax
  * put arg parsing detail into parse_command_line()
  * Updating configure script to version 1.7.0
  * Add strlen checking for IRQBALANCE_BANNED_CPUS
  * remove redundant "/" in SOCKET_TMPFS
  * Fix typo in service unit file
  * arm64: Add irq aff change check For aarch64, the PPIs format in /proc/interrputs can be parsed and add to interrupt db, and next, the number of interrupts is counted and used to calculate the load. Finally these interrupts maybe scheduled between the NUMA domains.
  * Correct typos in irqbalance.c
  * free cpu_ban_string when the next request come
  * improve irq migrate rule to avoid high irq load
  * make the option 'V' closer to the option with no arg
* Sun Aug 16 2020 Dirk Mueller <dmueller@suse.com>
- update to 1.7.0:
  * Strlen checking for IRQBALANCE_BANNED_CPU env var
  * Typo cleanup in SOCKET_TMPFS
  * consolidation of numa node creation on non-numa systems
  * fix uninitialized use of package_mask in affinity setup
  * use num_online_cpus instead of core_count
  * fix a null ptr crash in do_one_cpu
  * make list searching common from glib
  * fix a calloc parameter bug
  * remove some unused variables
  * use g_list_free_full
  * remove redundant call to free_cl_opts
  * fix some resource leaks in main()
  * fix some use after free issues in check_for_irq_ban
  * fix resource leaks in irqballance-ui, and in add_one_node
- remove Correct-capitalizing-in-service-file.patch: upstream
* Thu Jun 18 2020 Josef Möllers <josef.moellers@suse.com>
- Corrected mis-spelling (wrong CamelCase) of "EnvironmentFile"
  in misc/irqbalance.service
  [bsc#1172665, Correct-capitalizing-in-service-file.patch]
* Tue May 26 2020 Thomas Renninger <trenn@suse.de>
- Update to latest git HEAD version 0348a3b.
  There has been no version update for quite some time, but some
  restructuring and fixes we want to have included.
  D install-man-pages.patch
* Fri Apr 24 2020 Fabian Vogt <fvogt@suse.com>
- Package COPYING and README.md
- Add some deps for the -ui subpackage
* Thu Apr 23 2020 Thorsten Kukuk <kukuk@suse.com>
- Use fillup_prereq macro
- Move ui into sub-package to get minimal core much smaller
* Thu Jul 11 2019 trenn@suse.de
- Add git hash tag and date in version as source is derived from
  master/HEAD branch. Thanks to namtrac.
  This is done via _service file.
  Also add an example how to get back to a stable release version
- Update to latest git master version:
  git commit f7fdebbaa4dbc27fcdeb7
* Sun Jul  7 2019 Jan Engelhardt <jengelh@inai.de>
- Use noun phrase in summaries.
* Mon Jul  1 2019 trenn@suse.de
- Update to version 1.6.0 (b47eea84cbb93f533b0cba2f1aa):
  * fix balancing when numa information isn't available
  * Refine document about IRQBALANCE_BANNED_CPUS
  * Fix string truncation issues detected by GCC 8
  * fix socket path creation
  * Update document for option --banmod and --deepestcache
  * Fix ambiguous parsing of *node* entries in /sys.
  * procinterrupts: check xen-dyn-event more flexible
  * misc: Add an example for policy script
  * policyscript: ignore non-executable files when specifying a directory
  remove because already mainline:
  D fix_buffer_overflow_compiler.patch
* Thu Oct  4 2018 trenn@suse.de
- Allow compilation with SLE-12 and before by:
  * removing -std=C99 Latest compiler version does not complain
  anymore, SLE12 SPx and before did.
  * Fix a possible buffer overflow compiler warning
  A fix_buffer_overflow_compiler.patch
* Mon Oct  1 2018 egotthold@suse.com
- Removed aarch64-compile-fixes.patch because it is mainline now.
- Update to version 1.4.0:
  * Fixed an erroneous calculation of min_load that restricted candidates to a
    subset of objects
  * Fixed powerpc hotplug detection
  * Cleaned up syslog target dependency
  * Added some self test infrastructure (via make check)
- Update to version 1.3.0
  * New features in this release:
    optimization of platform device irq detection
    Added sample udev rules to trigger irq rescans on device add/remove
    Made irqbalance ui an optional compile component
    Added support for Intel CoD
    Add -v | --version option to command line
  * Bug fixes in this release:
    Misc compiler warning fixes and spelling errors
    Compilation error fix on aarch64
    Compilation error fix when using clang in c99 mode
    Unused variable cleanup
    Lots of memory leak cleanup in irqbalance-ui
    Prevent irqbalance from running in a container
    Fix irq affinity assignment in some cases to wrong numa node
    Fix oneshot mode
    exclude legacy irq 255
  * Deprecations:
    without-glib2 is removed, we just need it enough that we can't dummy it up
    anymore
* Thu Nov 23 2017 rbrown@suse.com
- Replace references to /var/adm/fillup-templates with new
  %%_fillupdir macro (boo#1069468)
* Wed Mar  1 2017 fschnizlein@suse.com
- Remove superfluous comment out man package packing
* Mon Feb  6 2017 dimstar@opensuse.org
- Switch to ncurses6: use ncurses6-config to find the correct
  CFLAGS and libraries (boo#1021328).
* Thu Jan 12 2017 dmueller@suse.com
- update to 1.2.0:
  * sort_irq logic rework to fix unintended ordering
  * removal of the affinity_hint infrastructure as its not needed
  * fixes for invalid cpumask parsing
  * many other minior fixes (see git log)
  * Aarch64 support
  * live interactive monitoring of irqbalance and live adjustment with irqbalance-ui
- remove fix-aarch64-support.patch: upstreamed
- add install-man-pages.patch
- add aarch64-compile-fixes.patch
* Fri Oct 14 2016 msuchanek@suse.com
- Set-fd-limit.patch: Increase limit on file descriptors (bsc#998399) (fate#321645)
* Tue Feb 23 2016 schwab@suse.de
- fix-aarch64-support.patch: Fix AArch64 support
* Sun Jan 17 2016 mpluskal@suse.com
- Update to 1.1.0
  * Banning support fixes
  * Load calculation improvements
  * Documentation fixes
  * Fix command line preservation across re-scan
  * Memory leak fixes
  * Misc. bug fixes
  * ARM irq support
  * New --banmod option
  * New sleep interval option
* Wed Nov 18 2015 mbrugger@suse.com
- Only exclude arch s390 and s390x
* Tue Nov 17 2015 mbrugger@suse.com
- enable build for aarch64
* Mon Nov  9 2015 dmueller@suse.com
- enable build for %%arm
* Mon Mar 16 2015 mpluskal@suse.com
- Clenup spec file with spec-cleaner
- Remove bug-893478_warn-once.patch
- Update to 1.0.9
  * PCI quirk support
  * System Logging compatibility
  * isolcpus inheritance
  * Misc. Bugfixes
* Fri Jan 23 2015 p.drouand@gmail.com
- Update to version 1.0.8
  * No ChangeLog available
- Fix home page and download source Url
- Update bug-893478_warn-once.patch; (submitted and accepted to/by
  upstream)
* Thu Sep 11 2014 trenn@suse.de
- Only warn once for affinity hint subset empty irqs (bnc#893478)
  * Add bug-893478_warn-once.patch
- Rename rcirq_balancer like the package name and the already renamed
  systemd service: rcirqbalance
* Mon Jun 16 2014 trenn@suse.de
- Change non-existing group: System/Environment/Daemons to System/Daemons
* Fri Jun 13 2014 trenn@suse.de
- Really fillup (and create) /etc/sysconfig/irqbalance file
- Remove IRQBALANCE_ONESHOT variable from sysconfig file.
  Default IRQBALANCE_ONESHOT=auto will be interpreted as --oneshot, other
  than documented in /etc/sysconfig/irqbalance. The same can be achieved via
  passing --oneshot via newly introduced IRQBALANCE_ARGS= variable (see below)
  bnc#874125
- The irqbalance.service file passes $IRQBALANCE_ARGS when the daemon
  is started. Provide it for the user via /etc/sysconfig/irqbalance.
* Wed Dec 11 2013 dvaleev@suse.com
- enable ppc64le
* Sun Oct 20 2013 p.drouand@gmail.com
- Update to version 1.0.7
  + No changelog available
- Drop sysvinit support as no target systems use it anymore
- Keep rcirq_balancer, make it symlink to /usr/sbin/service
- Remove syslog.target in irqbalance.service
  Please see http://lists.opensuse.org/archive/opensuse-packaging/2013-05/msg00102.html
- Change Group for valid one
* Thu Mar 28 2013 mmeister@suse.com
- Added url as source.
  Please see http://en.opensuse.org/SourceUrls
* Thu Nov 22 2012 rmilasan@suse.com
- Ensure that EnvironmentFile from irqbalance.service points to
  /etc/sysconfig/irqbalance environment config file.
* Thu Sep  6 2012 trenn@suse.de
- Update to version 1.0.4:
  New release of irqbalance, several minor cleanups and a few
  significant bug fixes and feature enhancements:
  - Fixed a divide by zero bug
  - Fixed a memory corruptor when items are not assigned to a specfic numa node
  - Added a banscript option, that allows a user defined script to be run to
    determine if a given irq should be excluded from balancing
  - Improve rescan ability to catch a timing race early in irqbalance setup
  - Added ability to force irqbalance to rescan irqs on reception of a SIGHUP.
  - Force affinity settings even if manually overridden outside of irqbalance.
  - Added a --foreground option to force foreground execution without debug output
* Mon Jun 25 2012 trenn@suse.de
- Correct bogus /etc/sysconfig/irqbalance comment:
  Service is started as daemon by default, on single and multi core
  systems
* Wed May  9 2012 trenn@suse.de
- Update to version 1.0.3 and make spec file to spec-cleaner clean.
* Thu Dec  1 2011 coolo@suse.com
- make it as exclusive as numactl
* Tue Nov 29 2011 crrodriguez@opensuse.org
- Use systemd macros in pre/post scripts
* Mon Oct 17 2011 trenn@suse.de
- Update to version 1.0
  - Remove files that are upstream: manpage, systemd config file
  - Introduction of highest topology level: Numa node
  - ...
* Sat Oct 15 2011 coolo@suse.com
- add libtool as buildrequire to make the spec file more reliable
* Tue Aug 16 2011 saschpe@suse.de
- Run spec-cleaner on spec file
- Don't start irqbalance by default, testing confirmed that it does
  not make any difference on machines with less than 32 cores
  nowadays (GKH's comment)
* Tue Jun  7 2011 aj@suse.de
- Add systemd service file.
* Sun Nov  7 2010 cristian.rodriguez@opensuse.org
- This is a long running service, use full RELRO here.
* Sat Oct  2 2010 cristian.rodriguez@opensuse.org
- update to version 0.56 in order to get libcap-ng support
  so irqbalance can drop privileges.
* Wed Jun 17 2009 crrodriguez@suse.de
- fix build when as-needed is a default linker option
* Wed Nov  5 2008 bwalle@suse.de
- Don't start the irqbalance on IA64 SGI SN2 systems (bnc#441505).
* Fri Aug 15 2008 bwalle@suse.de
- add "Required-Stop" to fix rpmlint error
* Tue Dec 11 2007 bwalle@suse.de
- add /etc/sysconfig/irqbalance configuration file for
  IRQBALANCE_ONESHOT, IRQBALANCE_BANNED_CPUS and
  IRQBALANCE_BANNED_INTERRUPTS configuration (#342593)
- fix some minor rpmlint warnings
* Thu Apr 26 2007 bwalle@suse.de
- remove special handling of timer interrupt and dual core
  systems from init script because the new irq balancer does
  that automatically
* Sun Apr 15 2007 bwalle@suse.de
- wrote manpage for irqbalance
* Wed Apr 11 2007 bwalle@suse.de
- updated to irqbalance.org 0.55
  o rewrite from static arrays to dynamic lists using glib
  o added IRQBALANCE_ONESHOT, IRQBALANCE_BANNED_INTERRUPTS
    IRQBALANCE_BANNED_CPUS configuration environment variables
- changed init script to not balance the timer interrupt due to
  broken hardware
- added $remote_fs to Required-Start since the binary needs
  glib2
* Tue Apr  3 2007 bwalle@suse.de
- increased IRQ number to (256 + (32*MAX_CPU)) as done in the
  x86_64 kernel
* Fri Jul 14 2006 sf@suse.de
- added patch from bug #171500, fixing regexps
* Tue May 16 2006 sf@suse.de
- added irqbalance-assert.diff to completely fix
  bug #158186 (see changelog entry below)
* Tue May  9 2006 sf@suse.de
- increase MAX_INTERRUPTS  to 512 to avoid
  segfault (bug #158186)
* Wed May  3 2006 sf@suse.de
- modified startscript to start irqbalancing only on real SMP
  machines (multisocket) (bug #171500)
* Wed Feb  8 2006 ak@suse.de
- increase max number of cpus to 128 (#146945)
- install manpage
* Wed Jan 25 2006 mls@suse.de
- converted neededforbuild to BuildRequires
* Mon Oct 31 2005 dmueller@suse.de
- don't build as root
* Fri Sep  2 2005 ro@suse.de
- rcscript: ignore on machines with < 2 CPUs
* Mon Jun 20 2005 ro@suse.de
- build with fPIE/pie
* Mon Feb 16 2004 sf@suse.de
- update to 0.09
* Sat Sep 20 2003 kukuk@suse.de
- Add PreRequires for insserv
* Thu Sep  4 2003 ro@suse.de
- added stop_on_removal and restart_on_update
- changed insserv_and_fillup to insserv_force_if_yast
* Thu Sep  4 2003 sf@suse.de
- added %%insserv_and_fillup in %%post
  and %%insserv_cleanup in %%postun
* Thu Sep  4 2003 ak@suse.de
- update to version 0.6
- Clean up init script a bit
- Move initscript outside tar and mark as source
* Fri Mar 21 2003 sf@suse.de
- initial version 0.1
